#' @title Function for finding a root of eta1
#' 
#' @description The function \code{eta1fn} searches the interval \code{lower} and
#' \code{upper} for a root (i.e., zero) of \code{eta1} in the three-parameter
#' exponential family of distribution.
#'
#' @param eta0 \code{n}
#' @param eta1 \code{nu/tau2+sum(y)}
#' @param eta2 \code{1/2*tau2}
#' @param logm a numeric value of the canonical parameter \code{theta}
#' @param ... other arguments
#'
#' @return write a returning value
#' @examples
#' # to be added
#' @note write notes
#' @section TODO:
#' write todo
#' @section FIXME:
#' write fixme
#' @keywords write keywords
#' @seealso write see also
#' @details write details
#' @references
#'
#' Lee (2013) ``Imprecise inferential framework'', PhD thesis.
#'
#' @author Chel Hee Lee <\email{gnustats@@gmail.com}>
#' @export
eta1fn <- function(eta0, eta1, eta2, logm, ztrunc=FALSE, method=c("LA", "AQ"), ...){
  
  stopifnot(!missing(eta0), !missing(eta1), !missing(eta2), !missing(logm))
  stopifnot(is.numeric(eta0), length(eta0)==1, is.numeric(eta1), length(eta1)==1, is.numeric(eta2), length(eta2)==1, is.numeric(logm), length(logm)==1)

  f1 <- function(theta, ...) exp(-eta2*theta^2 + eta1*theta - exp(log(eta0)+theta))
  k1 <- tryCatch(integrate(f1, lower=-Inf, upper=Inf)$value, 
    error=function(e) return(NaN))

  f2 <- function(theta, ...) theta*exp(-eta2*theta^2 + eta1*theta - exp(log(eta0)+theta))
  k2 <- tryCatch(integrate(f2, lower=-Inf, upper=Inf)$value, 
    error=function(e) return(NaN))

  thetaHat <- tryCatch(k2/k1, error=function(e) return(NaN))
  val <- thetaHat - logm  
  
  return(val)
}
NULL
