library(ipeglim)
rm(list=ls())

set.seed(1)
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/cpef2reg.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/cpef.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/model.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/iprior.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/update_imprecise.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/summary_imprecise.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/print_imprecise.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/plot_imprecise.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/plot_summary.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/pbox_imprecise.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/qc.R")
source("~/Documents/PhD/ipeglim/pkg/ipeglim/R/rvg4yx.R")
# iprior -> imprecisePrior

# structure of X
xm <- c(-3,2)
xsd <- c(3,2)
xr <- diag(2)
xr[2] <- xr[3] <- r <- 0
xsigma <- t(diag(xsd))%*%xr%*%diag(xsd)

# structure of B
bm <- c(0,0)
bsd <- c(1,1)
br <- diag(2)
br[1,2] <- br[2,1] <- r1 <- 0
Bmat <- t(diag(bsd))%*%br%*%diag(bsd)
Bmat <- Bmat*1e-2

# random variates generation
SILENCE <- FALSE
ZTRUNC <- TRUE
VERBOSE <- TRUE

tmp <- rvg4yx(N=1e2, pars=c(0.5, -0.5), xreg=TRUE, ztrunc=TRUE, kind="mvnorm", mean=xm, sigma=xsigma, center.X=TRUE)
dat <- tmp$yX
table(dat$y)

xi1 <- unlist(dat[1,-1])

m2fit <- model(formula=y~x1+x2-1, data=dat, ztrunc=ZTRUNC, dist="poisson")
cmfit <- iprior(obj=m2fit, circle=list(x0=0, y0=0, r=1, len=10))

# LAF is not working with the model including the intercept
olaf <- update(obj=cmfit, method="LAF", B=Bmat, xi=xi1, silent=SILENCE, control=list(flip=TRUE))
solaf <- summary(olaf, verbose=VERBOSE)

ola <- update(obj=cmfit, method="LA", B=Bmat, xi=xi1, silent=SILENCE)
sola <- summary(ola, verbose=VERBOSE)

print(solaf)
print(sola)

if(FALSE){
omh <- update(obj=cmfit, method="MH", B=Bmat, xi=xi1, silent=SILENCE)
somh <- summary(omh, verbose=VERBOSE)

ois <- update(obj=cmfit, method="IS", B=Bmat, xi=xi1, silent=SILENCE)
sois <- summary(ois, verbose=VERBOSE)

tb1 <- cbind(somh$est[,1], sola$est[,1], sois$est[,1], solaf$est[,1])
print(tb1)
tb2 <- cbind(somh$est[,2], sola$est[,2], sois$est[,2], solaf$est[,2])
print(tb2)


X11()
plot(sola, # for m0xtms
  main="Imprecise Posterior Shrinkage - Laplace", 
  sub=list(expression(-1<beta[1]~","~beta[2]<1), cex=1.25),
  xlab=expression(beta[1]),
  ylab=expression(beta[2]))

X11()
plot(somh, # for m0xtms
  main="Imprecise Posterior Shrinkage - Metropolis", 
  sub=list(expression(-1<beta[1]~","~beta[2]<1), cex=1.25),
  xlab=expression(beta[1]),
  ylab=expression(beta[2]))

X11()
plot(sois, # for m0xtms
  main="Imprecise Posterior Shrinkage - Importance", 
  sub=list(expression(-1<beta[1]~","~beta[2]<1), cex=1.25),
  xlab=expression(beta[1]),
  ylab=expression(beta[2]))

X11()
plot(solaf, # for m0xtms
  main="Imprecise Posterior Shrinkage - Laplace (Flip)", 
  sub=list(expression(-1<beta[1]~","~beta[2]<1), cex=1.25),
  xlab=expression(beta[1]),
  ylab=expression(beta[2]))
}
