\name{iprior}
\alias{iprior}
\alias{iprior.default}
\alias{iprior.imprecise}
\title{Imprecise Prior Specification}
\usage{
  iprior(obj, eqns = list(), circle = list(), x, mat,
    verbose = FALSE, ...)

  \method{iprior}{default} (obj, eqns = list(),
    circle = list(), x, mat, verbose = FALSE, ...)

  \method{iprior}{imprecise} (obj, eqns = list(),
    circle = list(), x, mat, verbose = FALSE, ...)
}
\arguments{
  \item{obj}{an object of class \code{imprecise} produced
  from \code{\link{model}}.}

  \item{eqns}{a list with components of \code{lhs} and
  \code{rhs}; See \sQuote{Details} for more information.}

  \item{circle}{a list with components of \code{x},
  \code{y}, \code{z}, \code{r}, and \code{len}.  See
  \sQuote{Details} for more information.}

  \item{x}{a numeric vector.}

  \item{mat}{a numeric matrix.}

  \item{verbose}{a logical value; Be more verbose about the
  process by displaying messages. Defaults to
  \code{FALSE}.}
}
\value{
  An object of class \code{imprecise} with the components:
  \item{stage}{the environment name called.}
  \item{xtms}{the list of solutions of the system
  supplied.}
}
\description{
  The function name \code{iprior} stands for
  \code{imprecise prior}. A set of $k$ linear inequality
  constraints is used for modelling \code{iprior}. The
  details of this specification are given under
  \sQuote{Details}.
}
\details{
  Modelling a prior ignorance is the second stage on the
  imprecise inferential framework. \code{stage} has the
  value \code{"iprior"} that is the name of environment
  called.

  A convex hull is defined by \code{lhs \%*\% x >= rhs},
  where \code{lhs} is a constraint matrix \eqn{k \times
  p}{k x p} and \code{rhs} is a constraint vector of length
  \eqn{k} from \eqn{k} linear inequality constraints. The
  function \code{iprior} searches for the solutions
  \code{xtms} of this system which are the extreme points
  of that convex hull.

  Depending on the numbers of dimensions \eqn{p} and
  constraints \eqn{k}, a shape of this convex hull is
  determined. For example, a box-constrained convex hull is
  made on \eqn{p=2} dimensional space with \eqn{k=4}
  constraints. When \eqn{k} has an infinite number, a
  nutural shape defaults to a \code{circle} on \eqn{p=2}
  dimensional space.
}
\note{
  Conventionally, the current version classifies a shape of
  convex hull into five categories: \code{eqns2d},
  \code{eqns3d}, \code{eqns4more}, \code{circle2d}, and
  \code{sphere3d} for visualization.

  It is a difficult task to sarch for extreme points in
  more than three dimensional cases. The function
  \code{convhulln} in the package \code{geometry} is a good
  replacement of \code{iprior}. (See more details about
  \code{convhulln} at
  \url{http://geometry.r-forge.r-project.org/}).
}
\examples{
\dontrun{
lc0 <- list(lhs=rbind(diag(2), -diag(2)), rhs=c(rep(-1,4)))
cmfit <- iprior(obj=m2fit, eqns=lc0)
plot(cmfit)
}
}
\author{
  Chel Hee Lee <\email{gnustats@gmail.com}>
}
\references{
  Lee (2013) ``Imprecise inferential framework'', PhD
  thesis.
}
\seealso{
  \code{\link{chull}}, \code{\link{convhulln}},
}
\keyword{constrained}
\keyword{convex}
\keyword{extreme}
\keyword{geometry,}
\keyword{hull,}
\keyword{optimization}
\keyword{points,}

