\name{model}
\alias{model}
\title{Describing Sampling Model for Imprecise Inferential Framework}
\usage{
  model(formula, data,
    dist = c("poisson", "binom", "geom"), ztrunc = FALSE,
    verbose = FALSE)
}
\arguments{
  \item{formula}{an object of class \code{\link{formula}};
  A symbolic description of the model to be fitted; The
  details of model specification are given under
  \sQuote{Details}.}

  \item{data}{an optional data frame, list or environment
  containing variables used for a description of the model
  in \code{\link{formula}}. If not found in \code{data},
  variables are taken from \code{environment(formula)},
  where the \code{model} is called.}

  \item{dist}{a sampling distribution of a response
  variable; Defaults to \code{poisson}. See
  \sQuote{Details}.}

  \item{ztrunc}{a logical value; Is the zero truncated?;
  Defaults to \code{FALSE}.}

  \item{verbose}{a logical value; Be more verbose about the
  process by displaying messages; Defaults to
  \code{FALSE}.}
}
\value{
  An object of class \code{imprecise} with the components:
  \item{xreg}{the logical value, Is the model described in
  \code{formula} regression?} \item{ztrunc}{the logical
  value supplied.} \item{formula}{the formula supplied.}
  \item{y}{the model reponse used in \code{formula}.}
  \item{X}{the model matrix used in \code{formula}.}
  \item{fit}{the object of classes \code{ztpreg} or
  \code{glm} depending on the value of \code{ztrunc}; the
  model is fitted by a maximum likelihood method.}
  \item{stage}{the environment name called.}
  \item{init}{the list of estrimates for parameters in
  \code{model} and and its variance-covariance matrix.}
}
\description{
  The function \code{model} is used to describe sampling
  models, specified by a symbolic description of the linear
  predictor in \code{\link{formula}}.
}
\details{
  The function \code{model} is the first task on performing
  an imprecise inferential framework. To tag this stage,
  \code{stage} has the character string \code{model} that
  is the name of environment called.

  All details are identical to those of
  \code{\link{formula}} in \code{\link{glm}}. In the
  context of regression, \code{y~0} represents a model that
  does not involve any variables in \code{data}. \code{y~1}
  represents a model that involve an intercept term, but no
  other variables in \code{data}. \code{y~.} represents a
  model that involve all variables in \code{data}.
}
\note{
  The current version provides the only sampling model
  \code{poisson}. In the near future, \code{binomial} and
  \code{normal} will be added.
}
\examples{
\dontrun{
# not provided yet
}
}
\author{
  Chel Hee Lee <\email{gnustats@gmail.com}>
}
\references{
  Lee (2013) ``Imprecise inferential framework'', PhD
  thesis.
}
\seealso{
  \code{\link{glm}}, \code{\link{formula}},
  \code{\link{ztpreg}}
}
\keyword{imprecise}
\keyword{models,}
\keyword{Poisson}
\keyword{regression,}
\keyword{zero-truncation,}

