\name{rvg4yx}
\alias{rvg4yx}
\title{Random variates generator for simulation studies}
\usage{
  rvg4yx(N, pars, xreg = FALSE, ztrunc = FALSE,
    kind = c("mvnorm", "mvbin", "norbin", "usrdef", "sknorm", "multinom", "poisson", "nbinom", "norbin", "gambin", "gambeta"),
    seed = NULL, shape = Inf, center.X = FALSE, ...)
}
\arguments{
  \item{N}{a number of random variates}

  \item{pars}{a vector of regression parameters}

  \item{ztrunc}{FALSE by default}

  \item{xreg}{FALSE by default}

  \item{seed}{NULL a random seed}

  \item{shape}{a shape parameter of gamma distribution}

  \item{...}{other arguments}

  \item{kind}{types of random variates}

  \item{center.X}{Are predictors centered at their means?}
}
\value{
  a list with components \item{n}{the number of
  observations which are actually realized} \item{y}{the
  \code{n}-by-\code{1} vector of response generated}
  \item{X}{the \code{n}-by-\code{p-1} matrix (an intercept
  is excluded)} \item{yX}{the \code{n}-by-\code{p} data
  frame which includes \code{y} and \code{X}}
}
\description{
  \code{rvg4yx} generates random variates of a response
  variable under the given conditions of mean and
  variance-covariance structure of matrices of predictors
  and their coefficients.
}
\details{
  The mean parameter of a response variable is a function
  of linear predictor by a link function in the context of
  generalized linear models.

  Log and logit links are supported.

  Default to \code{Xstr} is an independent multivariate
  normal distribution with mean \code{Xmean}, correlation
  \code{R}, and standard deviation \code{Xsd}.
}
\note{
  Default to a matrix decomposition \code{method} is
  \code{eigen}. Other options are \code{chol} and
  \code{svd}.

  Currently, the link \code{logit} is not supported.
}
\examples{
\dontrun{
tmp <- rvg4yx(N=5e2, pars=c(0.5, -0.5), ztrunc=TRUE, xreg=TRUE, kind="mvnorm", mean=xm, sigma=xsigma, center.X=TRUE)
dat <- tmp$yX
table(dat$y)
}
# y <- dat$y
# print(c(mean(y), dat$cm1))
# print(c(var(y), dat$cm2, dat$cm22))
# print(c(skewness(y), dat$g1))

# dat1 <- rvg4yx(N=1e1, xreg=FALSE, pars=2, ztrunc=TRUE, shape=4)
# y1 <- dat1$y
# print(c(mean(y1), dat1$cm1))
# print(c(var(y1), dat1$cm2, dat1$cm22, dat1$cm23))
# print(c(skewness(y1), dat1$g1))
}
\author{
  Chel Hee Lee <\email{gnustats@gmail.com}>
}
\seealso{
  \code{\link{rmvnorm}}, \code{\link{rmvbin}},
  \code{\link{rsn}}, \code{\link{rmsn}}
}

