\name{update.imprecise}
\alias{update}
\alias{update.imprecise}
\title{Updating Imprecise Prior}
\usage{
  \method{update}{imprecise} (object, silent = FALSE, ...)
}
\arguments{
  \item{object}{an object of class \code{imprecise}
  produced from \code{"\link{iprior}"}. See
  \sQuote{Details} for more information.}

  \item{silent}{a logical value; Would like to see the
  report of progress messages (including warnings and error
  messages) generated from numerical methods that are used
  for a numerical approximation? Defaults to \code{FALSE}.}

  \item{...}{Other named arguments to be passed to
  \code{\link{cpef}} and \code{\link{cpef2reg}}; needs to
  be matched exactly. See \sQuote{Details} for more
  information.}
}
\value{
  A list with the components: \item{m1}{The list containing
  all information of parameter estimation.}
  \item{method}{The type of numerical method used for
  numerical approximation} \item{xi}{The numeric vector for
  prediction if provided.}
}
\description{
  The function \code{update} applies to the Bayes rule to
  the imprecise prior which is specified by
  \code{"\link{iprior}"} by taking \code{data} in the
  \code{"\link{model}"}.
}
\details{
  The function \code{update} calls the functions of
  \code{\link{cpef}} and \code{\link{cpef2reg}} based on
  the \code{formula} specified in the \code{\link{model}}.
  Named arguements of \code{ztrunc}, \code{method}, and
  \code{apriori} are passed to those functions.

  This \code{update} is the last stage on the imprecise
  inferential framework. \code{stage} has the environment
  name called.

  \code{method} should be specified; Five options are
  available on the use of \code{\link{cpef}}; Three options
  are available on the use of \code{\link{cpef2reg}}. See
  the \sQuote{Details} of \code{\link{cpef}} and
  \code{\link{cpef2reg}}.

  In general, \code{MH} is safe from numerical failure on
  parameter estimation with a small size of a sample.
  \code{LA} is the most effieint for a large size of a
  sample (say, \eqn{n>5e2} for zero-truncated case).
}
\examples{
\dontrun{
##
}
}
\author{
  Chel Hee Lee <gnustats@gmail.com>
}
\references{
  Lee (2013) ``Imprecise inferential framework'', PhD
  thesis.
}
\seealso{
  \code{\link{iprior}}, \code{\link{model}},
  \code{\link{cpef}}, \code{\link{cpef2reg}}
}
\keyword{Bayes}
\keyword{framework,}
\keyword{Imprecise}
\keyword{inferential}
\keyword{Poisson}
\keyword{regression,}

