\name{ztpreg}
\alias{ztpreg}
\title{Zero-truncated Poisson and Negative Binomial Regression models with
Maximum likelihood estimation}
\usage{
  ztpreg(formula, data, dist = c("poisson", "nbinom"),
    method = c("BFGS", "L-BFGS-B"), hessian = TRUE,
    ztrunc = TRUE, ...)
}
\arguments{
  \item{formula}{a symbolic description of the model to be
  fit.}

  \item{data}{a data frame containg the variables in the
  model.}

  \item{dist}{a description of sampling model to be used in
  the model.}

  \item{method}{the method to be used in fitting model.
  The default method uses \code{BFGS} in the \code{optim}
  function.}

  \item{hessian}{logical, Should a numerically
  differentiated Hessian matrix about regression parameters
  be returned?}

  \item{ztrunc}{logical, Is the sampling model used in the
  model assumed that zeros are truncated?}

  \item{...}{other arguments}
}
\value{
  An object of class \code{ztpr} with components including
  \item{formula}{formula used to be fitted,}
  \item{converged}{integer code which indicates a
  successful completion of optimization process,}
  \item{niters}{integer that indicates a number of
  iterations until convergence to estimates,}
  \item{cfs}{estimated regression coefficients,}
  \item{vcv}{estimated variance-covariance matrix of
  regression coefficients which is obtained by the inverse
  of Hessian matrix} \item{llk}{value of log-likelihood
  function at \code{cfs}.}
}
\description{
  Zero-truncated Poisson and Negative Bionomial regression
  models are used for estimating the unknown population
  size using a single registration file in the stuides of
  Heijden (2003) and Cruffy (2008). Zero-truncated Negative
  Binomial is an alternative of zero-truncated Poisson
  model when an overdispersion is suspected.
}
\section{TODO}{
  \itemize{ \item Currently, \code{predict},
  \code{extractAIC}, \code{residuals}, \code{fitted},
  \code{residual plot}, \code{deviance} are not supported.
  \item Support another method of 'L-BFGS-B'. }
}
\examples{
#
# dat <- simulateYX(N=1e3, Xreg=FALSE, param=2, ztrunc=TRUE)
# y <- dat$y

# m <- ztpr(formula=y~1, ztrunc=TRUE, dist="poisson")
# fit <- summary(m, HT.est=TRUE, LM.test=TRUE)
# mhat <- exp(fit$cfs)
# print(fit$LM.chisq)
# print(c(fit$N, fit$cil, fit$ciu))
}
\author{
  Chel Hee Lee <\email{gnustats@gmail.com}>
}
\references{
  Peter GM van der Heijden, Rami Bustami, Maarten JLF
  Cruyff, Godfried Engbersen and Hans C van Houwelingen
  (2003), Point and interval estimation of the population
  size using the truncated Poisson regression model,
  \emph{Statistical Modelling}, \bold{3}, pp. 305-322.

  Cruyff MJ and van der Heijden (2008) Point and interval
  estimation of the population size using a zero-truncated
  negative binomial regression model, \emph{Biometrical
  Journal}, \bold{50}(6), pp. 1035-1050.

  Dankmar Boehning and Peter G. M. van der Heijden (2009),
  A Covarite adjustment for zero-truncated approaches to
  estimating the size of hidden and elusive populations,
  \emph{The Annals of Applied Statistics}, \bold{3}(2), pp.
  595-610.
}
\seealso{
  \code{\link{optim}}, \code{\link{glm.fit}}
}
\keyword{regression}
\keyword{zero-truncation}

